[license-shield-url]: https://img.shields.io/github/license/typeforce-js/is-string.svg?style=flat-square
[license-url]: https://github.com/Typeforce-JS/is-string/blob/master/LICENSE
[npm-downloads-shield-url]: https://img.shields.io/npm/dt/@typeforce/is-string.svg?style=flat-square
[npm-version-shield-url]: https://img.shields.io/npm/v/@typeforce/is-string.svg?style=flat-square
[npm-url]: https://www.npmjs.com/package/@typeforce/is-string
[unpkg-shield-url]: https://img.shields.io/badge/unpkg-up--to--date-brightgreen.svg?style=flat-square
[unpkg-url]: https://unpkg.com/@typeforce/is-string/dist/index.min.js

# is-string

[![NPM][npm-version-shield-url]][npm-url]
[![NPM][npm-downloads-shield-url]][npm-url]
[![CDN][unpkg-shield-url]][unpkg-url]
[![LICENSE][license-shield-url]][license-url]

Determine if a value is a string.

A value is a string if it is of primitive type `string`, or is an instance of
reference type `String`.

## Usage

```shell
    npm install @typeforce/is-string --save   # Install package via NPM
```

```javascript
    import { expect } from "chai";
    import isString from "@typeforce/is-string";

    expect(isString("Boo")).to.be.true;
    expect(isString("")).to.be.true;
    expect(isString(new String("Boo"))).to.be.true;

    expect(isString(undefined)).to.be.false;
    expect(isString(null)).to.be.false;
    expect(isString(42)).to.be.false;
```

This package contains TypeScript type declarations. Furthermore, the package
uses TypeScript type guards to allow type inference to influence IntelliSense.

```typescript
    if (isString(x)) {
        // IntelliSense now knows `x` is a string.
        let y: string = x;
    }
```

### Content Delivery Network (CDN)

This package can be imported via [unpkg](https://unpkg.com/#/) as demonstrated
below.

```html
    <script src="https://unpkg.com/@typeforce/is-string/dist/index.min.js"></script>
    <script type="application/javascript">
        var x = "foo";
        if (isString(x)) {
            // `x` is a string!
        }
    </script>
```

## Build & Test

When building the project, a folder named `dist/` will be created if it does not
already exist, where the compiled code will be outputted to. Type declaration
files will also be generated and outputted to the `dist/` folder.

A minified Javascript version of the entire project will be generated and
outputted to `dist/index.min.js`.

```shell
    npm install     # Installs dependencies.
    npm run build   # Build the project.
```

This package uses [Gulp](https://gulpjs.com/) for building, and [Chai](http://chaijs.com/)
and [Mocha](https://mochajs.org/) for testing.

```shell
    npm test       # Run tests.
```

## License

Refer to the `LICENSE` file for license information.
